==> mdm-api-0.1.4.65-20230901.083046-1-sources.jar: com/elitesland/cbpl/mdm/rpc/param/resp/StoreRpcDTO.java <==
package com.elitesland.cbpl.mdm.rpc.param.resp;

import com.elitescloud.cloudt.common.annotation.SysCode;
import com.elitescloud.cloudt.common.base.param.AbstractOrderQueryParam;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.time.LocalDate;

/**
 * @author eric.hao
 * @since 2023/05/23
 */
@Data
@ApiModel("门店主档数据")
public class StoreRpcDTO extends AbstractOrderQueryParam implements Serializable {

    @ApiModelProperty(value = "门店id")
    private Long storeId;

    @ApiModelProperty(value = "门店code")
    private String storeCode;

    @ApiModelProperty(value = "门店名称")
    private String storeName;

    @ApiModelProperty(value = "门店类型")
    private String storeType;

    @ApiModelProperty(value = "门店状态")
    private String storeStatus;

    @ApiModelProperty(value = "省编码")
    private String provinceCode;

    @ApiModelProperty(value = "城市code")
    private String cityCode;

    @ApiModelProperty("建店日期")
    private LocalDate foundDate;

    @ApiModelProperty("加盟商编码")
    private String franchiseeCode;

    @ApiModelProperty("加盟商名称")
    private String franchiseeName;

    @ApiModelProperty("子加盟商编码")
    private String subFranchiseeCode;

    @ApiModelProperty("子加盟商名称")
    private String subFranchiseeName;

    @ApiModelProperty("地址簿编码")
    private Long addrNo;

    @ApiModelProperty("是否白名单")
    private String isWhite;

    @ApiModelProperty("物流厂商")
    @SysCode(sys = "yst-inv", mod = "WMS_TYPE")
    private String wmsType;

    @ApiModelProperty("物流厂商中文")
    private String wmsTypeName;

    @ApiModelProperty("仓库编号")
    private String whCode;
    @ApiModelProperty("特许权收取比例")
    private String royaltyRate;
    @ApiModelProperty("推广费收取比例")
    private String promotionRate;
    @ApiModelProperty("城市")
    private String region;
    @ApiModelProperty("子加盟商")
    private String franchiseez;
    @ApiModelProperty("省")
    private String province;
    @ApiModelProperty("市")
    private String city;
}

==> mdm-api-0.1.4.68-25-03-20231025.105110-1-sources.jar: com/elitesland/cbpl/mdm/rpc/param/resp/StoreRpcDTO.java <==
package com.elitesland.cbpl.mdm.rpc.param.resp;

import com.elitescloud.cloudt.common.annotation.SysCode;
import com.elitescloud.cloudt.common.base.param.AbstractOrderQueryParam;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.time.LocalDate;
import java.util.List;

/**
 * @author eric.hao
 * @since 2023/05/23
 */
@Data
@ApiModel("门店主档数据")
public class StoreRpcDTO extends AbstractOrderQueryParam implements Serializable {

    @ApiModelProperty(value = "门店id")
    private Long storeId;

    @ApiModelProperty(value = "门店code")
    private String storeCode;

    @ApiModelProperty(value = "门店名称")
    private String storeName;

    @ApiModelProperty(value = "门店类型")
    private String storeType;

    @ApiModelProperty(value = "门店状态")
    private String storeStatus;

    @ApiModelProperty(value = "省编码")
    private String provinceCode;

    @ApiModelProperty(value = "城市code")
    private String cityCode;

    @ApiModelProperty("建店日期")
    private LocalDate foundDate;
    @ApiModelProperty("加盟商名称")
    private String franchiseeName;
    @ApiModelProperty("加盟商编码")
    private String franchiseeCode;
    @ApiModelProperty("加盟商编码")
    private List<String> franchiseeCodeList;

    @ApiModelProperty("子加盟商编码")
    private String subFranchiseeCode;

    @ApiModelProperty("子加盟商名称")
    private String subFranchiseeName;

    @ApiModelProperty("地址簿编码")
    private Long addrNo;

    @ApiModelProperty("是否白名单")
    private String isWhite;

    @ApiModelProperty("物流厂商")
    @SysCode(sys = "yst-inv", mod = "WMS_TYPE")
    private String wmsType;

    @ApiModelProperty("物流厂商中文")
    private String wmsTypeName;

    @ApiModelProperty("仓库编号")
    private String whCode;
    @ApiModelProperty("特许权收取比例")
    private String royaltyRate;
    @ApiModelProperty("推广费收取比例")
    private String promotionRate;
    @ApiModelProperty("城市")
    private String region;
    @ApiModelProperty("子加盟商")
    private String franchiseez;
    @ApiModelProperty("省")
    private String province;
    @ApiModelProperty("市")
    private String city;
    @ApiModelProperty("所属组织")
    private String affiliatedOrg;
}
